pub struct Jiffies(/* private fields */);Expand description
Jiffies is a term used to denote the units of time measurement by the kernel.
A jiffy represents one tick of the system timer interrupt,
whose frequency is equal to TIMER_FREQ Hz.
Implementations
Sourceimpl Jiffies
impl Jiffies
Sourcepub open spec fn duration_secs(self) -> u64
pub open spec fn duration_secs(self) -> u64
{ self@ / TIMER_FREQ }The whole-second component of this jiffy count.
Sourcepub open spec fn duration_nanos(self) -> u32
pub open spec fn duration_nanos(self) -> u32
{ (((self@ % TIMER_FREQ) * 1_000_000_000u64) / (TIMER_FREQ as int)) as u32 }The subsecond nanosecond component of this jiffy count.
Sourceimpl Jiffies
impl Jiffies
Sourcepub exec fn add(&mut self, jiffies: u64)
pub exec fn add(&mut self, jiffies: u64)
ensures
final(self)@ == old(self)@.saturating_add(jiffies),Adds the given number of jiffies, saturating at Jiffies::MAX on overflow.
Sourcepub exec fn as_duration(self) -> Duration
pub exec fn as_duration(self) -> Duration
returns
Duration::new(self.duration_secs(), self.duration_nanos()),Gets the Duration calculated from the jiffies counts.